{% load wagtailcore_tags %}

<article>
  <script id="vue-article-data"
          data-article-date="{{ page.visible_date|date }}" {# Formatted visible_date as date #}
          data-article-date-time="{{ page.visible_date|date:"c" }}" {# Formatted visible_date as datetime #}
          data-article-author="{{ page.owner.username | title }}" {# Formatted owner username as title #}
  >
  </script>
  {% for block in page.body %}
    {% if block.block_type != "detail" or render_detail %}
      <section class="block-{{ block.block_type }}">
        {% include_block block %}
      </section>
      {% block detail_link %}{% endblock %}
    {% endif %}
  {% endfor %}
</article>
{{ vue_message|json_script:"vue-message"}}
{{ initial_value|json_script:"initial-value"}}
<div id="app"></div>
